/// <reference types="node" />
import { CookieSerializeOptions } from "cookie";
import type { IncomingMessage, ServerResponse } from "http";
import type { GetServerSidePropsContext, GetServerSidePropsResult, NextApiRequest, NextApiResponse } from "next";
declare type password = string | {
    id: number;
    password: string;
}[];
interface IronSessionOptions {
    cookieName: string;
    password: password;
    ttl?: number;
    cookieOptions?: CookieSerializeOptions;
}
interface IronSession {
    set: <T = any>(name: string, value: T) => T;
    get: <T = any>(name: string) => T | undefined;
    unset: (name: string) => void;
    destroy: () => void;
    save: () => Promise<string>;
}
export interface NextApiRequestWithIronSession extends NextApiRequest {
    session: IronSession;
}
export declare type NextApiHandlerWithIronSession<T = any> = (req: NextApiRequestWithIronSession, res: NextApiResponse<T>) => void | Promise<void>;
interface NextGetSeverSideContextWithIronSession extends GetServerSidePropsContext {
    req: NextApiRequestWithIronSession;
}
export declare type NextGetServerSidePropsHandlerWithIronSession<P> = (context: NextGetSeverSideContextWithIronSession) => Promise<GetServerSidePropsResult<P>>;
export declare function withIronSessionRoute(handler: NextApiHandlerWithIronSession, options: IronSessionOptions): NextApiHandlerWithIronSession;
export declare function withIronSessionSsr<P>(handler: NextGetServerSidePropsHandlerWithIronSession<P>, options: IronSessionOptions): NextGetServerSidePropsHandlerWithIronSession<P>;
export declare function getIronSession<RequestType extends IncomingMessage, ResponseType extends ServerResponse>(req: RequestType, res: ResponseType, userOptions: IronSessionOptions): Promise<{
    set: <T = any>(name: string, value: T) => T;
    get: (name?: string | undefined) => any;
    unset: (name: string) => void;
    save(): Promise<string>;
    destroy(): void;
}>;
export {};
